@@ -18,6 +18,10 @@ function _aws_cdk_aws_rum_CfnAppMonitor(p) {
 }
 function _aws_cdk_aws_rum_CfnAppMonitor_AppMonitorConfigurationProperty(p) {
 }
+function _aws_cdk_aws_rum_CfnAppMonitor_MetricDefinitionProperty(p) {
+}
+function _aws_cdk_aws_rum_CfnAppMonitor_MetricDestinationProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -54,4 +58,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_rum_CfnAppMonitorProps, _aws_cdk_aws_rum_CfnAppMonitor, _aws_cdk_aws_rum_CfnAppMonitor_AppMonitorConfigurationProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_rum_CfnAppMonitorProps, _aws_cdk_aws_rum_CfnAppMonitor, _aws_cdk_aws_rum_CfnAppMonitor_AppMonitorConfigurationProperty, _aws_cdk_aws_rum_CfnAppMonitor_MetricDefinitionProperty, _aws_cdk_aws_rum_CfnAppMonitor_MetricDestinationProperty };
